@@ -19,8 +19,8 @@
 
 #include "kemailaddress.h"
 #include "kcodecs.h"
+#include "kcodecs_debug.h"
 
-#include <QDebug>
 #include <QUrl>
 
 #include <QtCore/QRegExp>
@@ -101,13 +101,13 @@ QStringList KEmailAddress::splitAddressList(const QString &aStr)
 
 //-----------------------------------------------------------------------------
 // Used by KEmailAddress::splitAddress(...) and KEmailAddress::firstEmailAddress(...).
-KEmailAddress::EmailParseResult splitAddressInternal(const QByteArray  address,
+KEmailAddress::EmailParseResult splitAddressInternal(const QByteArray &address,
                                                      QByteArray &displayName,
                                                      QByteArray &addrSpec,
                                                      QByteArray &comment,
                                                      bool allowMultipleAddresses)
 {
-    //  qDebug() << "address";
+    //  qCDebug(KCODECS_LOG) << "address";
     displayName = "";
     addrSpec = "";
     comment = "";
@@ -259,9 +259,9 @@ KEmailAddress::EmailParseResult splitAddressInternal(const QByteArray  address,
         }
     }
     /*
-      qDebug() << "display-name : \"" << displayName << "\"";
-      qDebug() << "comment      : \"" << comment << "\"";
-      qDebug() << "addr-spec    : \"" << addrSpec << "\"";
+      qCDebug(KCODECS_LOG) << "display-name : \"" << displayName << "\"";
+      qCDebug(KCODECS_LOG) << "comment      : \"" << comment << "\"";
+      qCDebug(KCODECS_LOG) << "addr-spec    : \"" << addrSpec << "\"";
     */
     return AddressOk;
 }
@@ -512,7 +512,7 @@ KEmailAddress::EmailParseResult KEmailAddress::isValidAddressList(const QString
     QStringList::const_iterator it = list.begin();
     EmailParseResult errorCode = AddressOk;
     for (it = list.begin(); it != list.end(); ++it) {
-        qDebug() << " *it" << (*it);
+        qCDebug(KCODECS_LOG) << " *it" << (*it);
         errorCode = isValidAddress(*it);
         if (errorCode != AddressOk) {
             badAddr = (*it);
@@ -668,7 +668,7 @@ QByteArray KEmailAddress::extractEmailAddress(const QByteArray &address, QString
         addrSpec = QByteArray();
         if (result != AddressEmpty) {
             errorMessage = emailParseResultToString(result);
-            qDebug() << "Input:" << address << "\nError:"
+            qCDebug(KCODECS_LOG) << "Input:" << address << "\nError:"
                      << errorMessage;
         }
     } else {
@@ -708,7 +708,7 @@ QByteArray KEmailAddress::firstEmailAddress(const QByteArray &addresses, QString
         if (result != AddressEmpty) {
 
             errorMessage = emailParseResultToString(result);
-            qDebug() << "Input: aStr\nError:"
+            qCDebug(KCODECS_LOG) << "Input: aStr\nError:"
                      << errorMessage;
         }
     } else {
@@ -1009,7 +1009,7 @@ QString KEmailAddress::toIdn(const QString &addrSpec)
 //-----------------------------------------------------------------------------
 QString KEmailAddress::normalizeAddressesAndDecodeIdn(const QString &str)
 {
-    //  qDebug() << str;
+    //  qCDebug(KCODECS_LOG) << str;
     if (str.isEmpty()) {
         return str;
     }
@@ -1037,17 +1037,17 @@ QString KEmailAddress::normalizeAddressesAndDecodeIdn(const QString &str)
         }
     }
     /*
-      qDebug() << "normalizedAddressList: \""
+      qCDebug(KCODECS_LOG) << "normalizedAddressList: \""
                << normalizedAddressList.join( ", " )
                << "\"";
     */
-    return normalizedAddressList.join(QLatin1String(", "));
+    return normalizedAddressList.join(QStringLiteral(", "));
 }
 
 //-----------------------------------------------------------------------------
 QString KEmailAddress::normalizeAddressesAndEncodeIdn(const QString &str)
 {
-    //qDebug() << str;
+    //qCDebug(KCODECS_LOG) << str;
     if (str.isEmpty()) {
         return str;
     }
@@ -1072,11 +1072,11 @@ QString KEmailAddress::normalizeAddressesAndEncodeIdn(const QString &str)
     }
 
     /*
-      qDebug() << "normalizedAddressList: \""
+      qCDebug(KCODECS_LOG) << "normalizedAddressList: \""
                << normalizedAddressList.join( ", " )
                << "\"";
     */
-    return normalizedAddressList.join(QLatin1String(", "));
+    return normalizedAddressList.join(QStringLiteral(", "));
 }
 
 //-----------------------------------------------------------------------------
@@ -1129,7 +1129,7 @@ QUrl KEmailAddress::encodeMailtoUrl(const QString &mailbox)
 {
     const QByteArray encodedPath = KCodecs::encodeRFC2047String(mailbox, "utf-8");
     QUrl mailtoUrl;
-    mailtoUrl.setScheme(QLatin1String("mailto"));
+    mailtoUrl.setScheme(QStringLiteral("mailto"));
     mailtoUrl.setPath(QLatin1String(encodedPath));
     return mailtoUrl;
 }
